@@ -63,18 +63,18 @@
 #' summary(fit.mg)
 #' 
 #' @export
-cum.residuals<-function(object,data=sys.parent(),modelmatrix=0,cum.resid=1,n.sim=500,
+cum.residuals<-function(object,data=parent.frame(),modelmatrix=0,cum.resid=1,n.sim=500,
 	weighted.test=0,max.point.func=50,weights=NULL)
 { ## {{{
 ## {{{ setting up
   start.design<-1; silent <- 1; offsets <- NULL; 
-  if (!(class(object)!="aalen" | class(object)!="timecox" | class(object)!="cox.aalen" ))
+  if (!inherits(object,c("aalen","timecox","cox.aalen" )))
     stop ("Must be output from aalen() timecox() or cox.aalen() functions\n") 
-  if (class(object)=="timecox") if (object$method!="basic") 
+  if (inherits(object,"timecox")) if (object$method!="basic") 
     stop("Residuals available only for method=basic\n")
-  if (class(object)=="timecox") if (is.null(object$gamma)==FALSE) 
+  if (inherits(object,"timecox")) if (is.null(object$gamma)==FALSE) 
     stop("Residuals available only for timecox model with no const terms\n")
-  if (class(object)=="aalen") if (is.null(object$gamma)==FALSE) 
+  if (inherits(object,"aalen")) if (is.null(object$gamma)==FALSE) 
     stop("Residuals available only for Aalen model with no const terms\n")
   if (is.null(object$residuals$dM)==TRUE) stop("Residuals not computed, add option residuals=1\n");
   if (sum(modelmatrix)==0 && cum.resid==0) 
@@ -82,7 +82,7 @@ cum.residuals<-function(object,data=sys.parent(),modelmatrix=0,cum.resid=1,n.sim
   stratum <- attr(object,"stratum"); 
   rate.sim <- 1; 
   weights1 <- NULL
-  if (class(object)=="cox.aalen") {
+  if (inherits(object,"cox.aalen")) {
     dcum<-apply(as.matrix(object$cum[,-1]),2,diff); 
     beta<-object$gamma; 
     coxaalen<-1; 
@@ -100,9 +100,10 @@ cum.residuals<-function(object,data=sys.parent(),modelmatrix=0,cum.resid=1,n.sim
   clust<-unique(cluster); 
   antclust<-length(clust); 
 
-  if (class(object)=="cox.aalen") 
+  if (inherits(object,"cox.aalen"))
   ldata<-aalen.des(formula,data,model="cox.aalen") else ldata<-aalen.des(formula,data) 
   X<-ldata$X; covar<-X; px<-ldata$px; 
+  if (length(ldata$covnamesX)==ncol(covar)) colnames(covar) <- ldata$covnamesX
 
   time<-attr(object,"start"); 
   time2<-attr(object,"stop"); 
@@ -346,7 +347,6 @@ cum.residuals<-function(object,data=sys.parent(),modelmatrix=0,cum.resid=1,n.sim
 } ## }}}
 
 
-
 #' Plots cumulative residuals
 #' 
 #' This function plots the output from the cumulative residuals function
@@ -606,7 +606,7 @@ cum.residuals<-function(object,data=sys.parent(),modelmatrix=0,cum.resid=1,n.sim
 #' 
 "summary.cum.residuals" <- function (object,digits=3,...) 
 {## {{{
-  if (!inherits(object, 'cum.residuals')) stop ("Must be an cum.residuals object")
+  if (!inherits(object,'cum.residuals')) stop ("Must be an cum.residuals object")
 
   # We print information about object:  
   cat("Test for cumulative MG-residuals \n\n")
